@@ -25,7 +25,6 @@ def edit_page(request, path):
 """
 from django.shortcuts import render
 from django.http import HttpResponseRedirect
-from pagetree.helpers import get_module, needs_submit, submitted
 from pagetree.helpers import get_section_from_path
 
 
@@ -68,6 +67,25 @@ def reset_page(section, request):
     return HttpResponseRedirect(section.get_absolute_url())
 
 
+class UserPageVisitor(object):
+    """ simplify/centralize logging visits
+
+    automatically does nothing for an anonymous user
+    """
+    def __init__(self, section, user):
+        self.section = section
+        self.user = user
+
+    def visit(self, status=None):
+        if self.user.is_anonymous():
+            return
+        if not status:
+            status = "complete"
+            if self.section.needs_submit():
+                status = "incomplete"
+        self.section.user_pagevisit(self.user, status)
+
+
 def generic_view_page(request, path, hierarchy="main",
                       template="pagetree/page.html",
                       extra_context=None,
@@ -88,22 +106,26 @@ def generic_view_page(request, path, hierarchy="main",
     """
     section = get_section_from_path(path, hierarchy=hierarchy)
     root = section.hierarchy.get_root()
-    module = get_module(section)
+    module = section.get_module()
     if section.is_root():
         return visit_root(section, no_root_fallback_url)
 
+    upv = UserPageVisitor(section, request.user)
     if request.method == "POST":
         # user has submitted a form. deal with it
         if request.POST.get('action', '') == 'reset':
+            upv.visit(status="incomplete")
             return reset_page(section, request)
+        upv.visit(status="complete")
         return page_submit(section, request)
     else:
+        upv.visit()
         instructor_link = has_responses(section)
         context = dict(
             section=section,
             module=module,
-            needs_submit=needs_submit(section),
-            is_submitted=submitted(section, request.user),
+            needs_submit=section.needs_submit(),
+            is_submitted=section.submitted(request.user),
             modules=root.get_children(),
             root=section.hierarchy.get_root(),
             instructor_link=instructor_link,
@@ -135,7 +157,7 @@ def generic_instructor_page(request, path, hierarchy="main",
                and p.block().needs_submit()]
     context = dict(section=section,
                    quizzes=quizzes,
-                   module=get_module(section),
+                   module=section.get_module(),
                    modules=root.get_children(),
                    root=section.hierarchy.get_root())
     if extra_context:
@@ -161,7 +183,7 @@ def generic_edit_page(request, path, hierarchy="main",
     root = section.hierarchy.get_root()
     context = dict(
         section=section,
-        module=get_module(section),
+        module=section.get_module(),
         modules=root.get_children(),
         available_pageblocks=section.available_pageblocks(),
         root=section.hierarchy.get_root())
