@@ -79,12 +79,12 @@ class Hierarchy(models.Model):
             return []
 
     def get_first_leaf(self, section):
-        if (section.is_leaf()):
+        if section.is_leaf():
             return section
         return self.get_first_leaf(section.get_children()[0])
 
     def get_last_leaf(self, section):
-        if (section.is_leaf()):
+        if section.is_leaf():
             return section
         return self.get_last_leaf(list(section.get_children())[-1])
 
@@ -315,12 +315,12 @@ class Section(MP_Node):
         return EditForm()
 
     def get_first_leaf(self):
-        if (self.is_leaf()):
+        if self.is_leaf():
             return self
         return self.get_children()[0].get_first_leaf()
 
     def get_last_leaf(self):
-        if (self.is_leaf()):
+        if self.is_leaf():
             return self
         return list(self.get_children())[-1].get_last_leaf()
 
@@ -355,6 +355,32 @@ class Section(MP_Node):
                         proceed = not p.block().redirect_to_self_on_submit()
         return proceed
 
+    def needs_submit(self):
+        """ if any blocks on the page need to be submitted """
+        for p in self.pageblock_set.all():
+            if hasattr(p.block(), 'needs_submit'):
+                if p.block().needs_submit():
+                    return True
+        return False
+
+    def submitted(self, user):
+        """ if all blocks on the page that require submissions
+        have been submitted """
+        for p in self.pageblock_set.all():
+            if hasattr(p.block(), 'needs_submit'):
+                if p.block().needs_submit():
+                    try:
+                        s = p.block().unlocked(user)
+                        if not s:
+                            # there's an unsubmitted block
+                            return False
+                    except:
+                        # most likely: no unlocked() method
+                        pass
+        # made it all the way through without any blocks
+        # reporting that they are unsubmitted
+        return True
+
     def as_dict(self):
         return dict(
             label=self.label,
